==> fulcro.ui.bulma-0.1.0.jar: META-INF/leiningen/org.photonsphere/fulcro.ui.bulma/README.md <==
# org.photonsphere/fulcro.ui.bulma

A fulcro.ui.bootstrap3 inspired Clojure library for Bulma, to be used with Fulcro -- Mari Donkers (photonsphere.org).

(Twitter: @maridonkers | Google+: +MariDonkers | GitHub: maridonkers)

## Rationale

A purposely 'thin' Clojure library for the lean CSS-only, [Flexbox](https://en.wikipedia.org/wiki/CSS_Flex_Box_Layout) based, [Bulma](https://github.com/jgthms/bulma) framework. Work in progress. Intention is to *not* implement the straight forward Bulma components and elements. For example rendering and adding ClojureScript to a Bulma button is relatively straightforward. More complex Bulma components, such as a Navbar and a Dropdown, will be supported by this library.

## Currently implemented Bulma components

* Navbar
* Dropdown

## Github

The source code to the Fulcro-Bulma library can be found on Github: [Fulcro-Bulma](https://github.com/maridonkers/fulcro-bulma)

## Usage

In your project.clj use the following dependency:

`[org.photonsphere/fulcro.ui.bulma "0.1.0"]`

Also see the file docs/intro.md.

## Copyright and License

Source code obtained from [Om Next[(https://github.com/omcljs/om) is:

Copyright © 2013-2017 David Nolen

Licensed under the Eclipse Public License.

[Fulcro](https://github.com/fulcrologic/fulcro) is:

Copyright (c) 2018, Fulcrologic, LLC
The MIT License (MIT)

The [Fulcro-Bulma](https://github.com/maridonkers/fulcro-bulma) library is:

Copyright (c) 2018, Mari Donkers (photonsphere.org; Twitter: @maridonkers | Google+: +MariDonkers | GitHub: maridonkers)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> fulcro.ui.bulma-0.1.1.jar: META-INF/leiningen/org.photonsphere/fulcro.ui.bulma/README.md <==
# org.photonsphere/fulcro.ui.bulma

A fulcro.ui.bootstrap3 inspired Clojure library for Bulma, to be used with Fulcro -- Mari Donkers (photonsphere.org).

(Twitter: @maridonkers | Google+: +MariDonkers | GitHub: maridonkers)

## Rationale

A purposely 'thin' Clojure library for the lean CSS-only, [Flexbox](https://en.wikipedia.org/wiki/CSS_Flex_Box_Layout) based, [Bulma](https://github.com/jgthms/bulma) framework. Work in progress. Intention is to *not* implement the straight forward Bulma components and elements. For example rendering and adding ClojureScript to a Bulma button is relatively straightforward. More complex Bulma components, such as a Navbar and a Dropdown, will be supported by this library.

## Currently implemented Bulma components

* Navbar
* Dropdown

## Github

The source code to the Fulcro-Bulma library can be found on Github: [Fulcro-Bulma](https://github.com/maridonkers/fulcro-bulma)

## Usage (via Clojars)

The library is on Clojars: [org.photonsphere/fulcro.ui.bulma](https://clojars.org/org.photonsphere/fulcro.ui.bulma). In your project.clj use the following dependency:

`[org.photonsphere/fulcro.ui.bulma "0.1.1"]`

Also see the file docs/intro.md.

## Copyright and License

Source code obtained from [Om Next[(https://github.com/omcljs/om) is:

Copyright © 2013-2017 David Nolen

Licensed under the Eclipse Public License.

[Fulcro](https://github.com/fulcrologic/fulcro) is:

Copyright (c) 2018, Fulcrologic, LLC
The MIT License (MIT)

The [Fulcro-Bulma](https://github.com/maridonkers/fulcro-bulma) library is:

Copyright (c) 2018, Mari Donkers (photonsphere.org; Twitter: @maridonkers | Google+: +MariDonkers | GitHub: maridonkers)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
